@@ -2,7 +2,7 @@ package FBP::Control;
 
 use Mouse;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 extends 'FBP::Window';
 
@@ -11,10 +11,4 @@ has default => (
 	isa => 'Bool',
 );
 
-has permission => (
-	is       => 'ro',
-	isa      => 'Str',
-	required => 1,
-);
-
 1;
