@@ -2,16 +2,10 @@ package FBP::HtmlWindow;
 
 use Mouse;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 extends 'FBP::Window';
 
-has permission => (
-	is  => 'ro',
-	isa => 'Str',
-	required => 1,
-);
-
 has style => (
 	is  => 'ro',
 	isa => 'Str',
